# Generated by roxygen2: do not edit by hand

S3method(plot,adjmat)
S3method(plot,blkmat)
S3method(plot,penderiv)
S3method(print,performance)
export(compute_derivative)
export(compute_penalty)
export(gen_prec_sbm)
export(grasps)
export(performance)
export(prec_to_adj)
export(sparsify_block_banded)
import(ggforce)
import(ggplot2)
importFrom(Rcpp,evalCpp)
importFrom(Rdpack,reprompt)
importFrom(grDevices,colorRampPalette)
importFrom(igraph,as_adjacency_matrix)
importFrom(igraph,sample_sbm)
importFrom(scales,rescale)
importFrom(stats,cov)
useDynLib(grasps, .registration = TRUE)
